@@ -138,6 +138,7 @@ class ContainerManager:
         extra_envs: Dict = None,
         network_mode="bridge",
         background=False,
+        labels=None
     ):
         timer = CodeTimer(name=self.container_desc.name, silent=True, unit="s")
         # start sidecars
@@ -178,6 +179,7 @@ class ContainerManager:
                 command=[str(val) for val in self.container_desc.command],
                 network_mode=network_mode,
                 links=links,
+                labels=self.container_desc.get_labels(extra_labels=labels)
             )
             if not background:
                 self.recieve_logs()
